@@ -44,6 +44,7 @@ package Sidef::Types::Array::Pair {
             $addr{$refaddr};
         };
 
+        no warnings 'redefine';
         local *Sidef::Types::Array::Pair::get_value = $sub;
         $sub->($_[0]);
     }
@@ -68,14 +69,14 @@ package Sidef::Types::Array::Pair {
 
     sub to_hash {
         my ($self) = @_;
-        Sidef::Types::Hash::Hash->new(@{$self});
+        Sidef::Types::Hash::Hash->new(@$self);
     }
 
     *to_h = \&to_hash;
 
     sub to_array {
         my ($self) = @_;
-        Sidef::Types::Array::Array->new(@{$self});
+        Sidef::Types::Array::Array->new(@$self);
     }
 
     *to_a = \&to_array;
@@ -100,6 +101,7 @@ package Sidef::Types::Array::Pair {
               . join(', ', map { (ref($_) && ($s = UNIVERSAL::can($_, 'dump'))) ? $s->($_) : ($_ // 'nil') } @$obj) . ')';
         };
 
+        no warnings 'redefine';
         local *Sidef::Types::Array::Pair::dump = $sub;
         $sub->($_[0]);
     }
