@@ -5,7 +5,7 @@ package Sidef::Types::Glob::Dir {
 
     use parent qw(
       Sidef::Types::Glob::File
-      );
+    );
 
     require Encode;
     require File::Spec;
@@ -52,6 +52,44 @@ package Sidef::Types::Glob::Dir {
 
     *temp = \&tmp;
 
+    sub mktemp {
+        my ($self, %opts) = @_;
+        state $x = require File::Temp;
+        __PACKAGE__->new(File::Temp::tempdir(CLEANUP => 1, %opts));
+    }
+
+    *make_tmp  = \&mktemp;
+    *make_temp = \&mktemp;
+
+    sub find {
+        my ($self, $arg) = @_;
+        state $x = require File::Find;
+
+        my @files;
+        my $ref      = ref($arg // '');
+        my $is_block = $ref eq 'Sidef::Types::Block::Block';
+
+        File::Find::find(
+            sub {
+                my $file = Encode::decode_utf8($File::Find::name);
+
+                if (-d $file) {
+                    $file = __PACKAGE__->new($file);
+                }
+                else {
+                    $file = Sidef::Types::Glob::File->new($file);
+                }
+
+                $is_block ? $arg->run($file) : push(@files, $file);
+            },
+            $$self
+        );
+
+        $is_block ? $self : Sidef::Types::Array::Array->new(\@files);
+    }
+
+    *browse = \&find;
+
     sub cwd {
         state $x = require Cwd;
         __PACKAGE__->new(Encode::decode_utf8(Cwd::getcwd()));
